@@ -26,6 +26,7 @@ describe 'ironic::conductor' do
     { :package_ensure                => 'present',
       :enabled                       => true,
       :enabled_drivers               => ['pxe_ipmitool'],
+      :enabled_hardware_types        => ['ipmi'],
       :max_time_interval             => '120',
       :force_power_state_during_sync => true }
   end
@@ -63,96 +64,112 @@ describe 'ironic::conductor' do
 
     it 'configures ironic.conf' do
       is_expected.to contain_ironic_config('DEFAULT/enabled_drivers').with_value('pxe_ipmitool')
+      is_expected.to contain_ironic_config('DEFAULT/enabled_hardware_types').with_value('ipmi')
       is_expected.to contain_ironic_config('conductor/max_time_interval').with_value(p[:max_time_interval])
       is_expected.to contain_ironic_config('conductor/force_power_state_during_sync').with_value(p[:force_power_state_during_sync])
       is_expected.to contain_ironic_config('conductor/automated_clean').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/api_url').with(:value => '<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('glance/swift_account').with(:value => '<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('glance/swift_temp_url_key').with(:value => '<SERVICE DEFAULT>').with_secret(true)
-      is_expected.to contain_ironic_config('glance/swift_temp_url_duration').with(:value => '<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('neutron/cleaning_network_uuid').with(:value => '<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('neutron/provisioning_network_uuid').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('neutron/cleaning_network').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('neutron/provisioning_network').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('deploy/continue_if_disk_secure_erase_fails').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('deploy/http_url').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('deploy/http_root').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/configdrive_use_swift').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/configdrive_swift_container').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/inspect_timeout').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('deploy/default_boot_option').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('neutron/port_setup_delay').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/power_state_change_timeout').with(:value => '<SERVICE DEFAULT>')
     end
 
     context 'when overriding parameters' do
       before :each do
         params.merge!(
-          :enabled_drivers               => ['pxe_ssh', 'agent_ssh'],
+          :enabled_drivers               => ['pxe_ilo', 'agent_ilo'],
+          :enabled_hardware_types        => ['ipmi', 'irmc'],
           :max_time_interval             => '50',
           :force_power_state_during_sync => false,
           :automated_clean               => false,
-          :swift_account                 => '00000000-0000-0000-0000-000000000000',
-          :swift_temp_url_key            => 'the-key',
-          :swift_temp_url_duration       => 3600,
-          :cleaning_network_uuid         => '00000000-0000-0000-0000-000000000000',
+          :cleaning_network              => '00000000-0000-0000-0000-000000000000',
           :api_url                       => 'https://127.0.0.1:6385',
-          :provisioning_network_uuid     => '00000000-0000-0000-0000-000000000000',
+          :provisioning_network          => '00000000-0000-0000-0000-000000000000',
           :cleaning_disk_erase           => 'metadata',
           :http_url                      => 'http://host:port',
           :http_root                     => '/src/www',
           :configdrive_use_swift         => true,
           :configdrive_swift_container   => 'cont',
+          :default_boot_option           => 'local',
+          :port_setup_delay              => '15',
+          :power_state_change_timeout    => '300'
         )
       end
       it 'should replace default parameter with new value' do
-        is_expected.to contain_ironic_config('DEFAULT/enabled_drivers').with_value('pxe_ssh,agent_ssh')
+        is_expected.to contain_ironic_config('DEFAULT/enabled_drivers').with_value('pxe_ilo,agent_ilo')
+        is_expected.to contain_ironic_config('DEFAULT/enabled_hardware_types').with_value('ipmi,irmc')
         is_expected.to contain_ironic_config('conductor/max_time_interval').with_value(p[:max_time_interval])
         is_expected.to contain_ironic_config('conductor/force_power_state_during_sync').with_value(p[:force_power_state_during_sync])
         is_expected.to contain_ironic_config('conductor/automated_clean').with_value(p[:automated_clean])
         is_expected.to contain_ironic_config('conductor/api_url').with_value(p[:api_url])
-        is_expected.to contain_ironic_config('glance/swift_account').with_value(p[:swift_account])
-        is_expected.to contain_ironic_config('glance/swift_temp_url_key').with_value(p[:swift_temp_url_key]).with_secret(true)
-        is_expected.to contain_ironic_config('glance/swift_temp_url_duration').with_value(p[:swift_temp_url_duration])
-        is_expected.to contain_ironic_config('neutron/cleaning_network_uuid').with_value('00000000-0000-0000-0000-000000000000')
-        is_expected.to contain_ironic_config('neutron/provisioning_network_uuid').with_value('00000000-0000-0000-0000-000000000000')
+        is_expected.to contain_ironic_config('neutron/cleaning_network').with_value('00000000-0000-0000-0000-000000000000')
+        is_expected.to contain_ironic_config('neutron/provisioning_network').with_value('00000000-0000-0000-0000-000000000000')
         is_expected.to contain_ironic_config('deploy/erase_devices_priority').with_value(0)
         is_expected.to contain_ironic_config('deploy/erase_devices_metadata_priority').with_value(10)
         is_expected.to contain_ironic_config('deploy/http_url').with_value(p[:http_url])
         is_expected.to contain_ironic_config('deploy/http_root').with_value(p[:http_root])
         is_expected.to contain_ironic_config('conductor/configdrive_use_swift').with_value(p[:configdrive_use_swift])
         is_expected.to contain_ironic_config('conductor/configdrive_swift_container').with_value(p[:configdrive_swift_container])
+        is_expected.to contain_ironic_config('deploy/default_boot_option').with_value(p[:default_boot_option])
+        is_expected.to contain_ironic_config('neutron/port_setup_delay').with_value(p[:port_setup_delay])
+        is_expected.to contain_ironic_config('conductor/power_state_change_timeout').with_value(p[:power_state_change_timeout])
       end
     end
 
+    context 'when overriding parameters' do
+      before :each do
+        params.merge!(
+          :provisioning_network_name => 'abc',
+          :cleaning_network_name => 'abc',
+        )
+      end
+      it 'should set provisioning/cleaning with new value' do
+          is_expected.to contain_ironic_config('neutron/cleaning_network').with_value('abc').with_transform_to('net_uuid')
+          is_expected.to contain_ironic_config('neutron/provisioning_network').with_value('abc').with_transform_to('net_uuid')
+      end
+    end
+
+
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
+
+        case facts[:osfamily]
+        when 'Debian'
+          let :platform_params do
+            { :conductor_package => 'ironic-conductor',
+              :conductor_service => 'ironic-conductor' }
+          end
+          # https://bugs.launchpad.net/cloud-archive/+bug/1572800
+          it 'installs ipmitool package' do
+            is_expected.to contain_package('ipmitool').with(
+              :ensure => 'present',
+              :name   => 'ipmitool',
+              :tag    => ['openstack', 'ironic-package'],
+            )
+          end
+        when 'RedHat'
+          let :platform_params do
+            { :conductor_service => 'ironic-conductor' }
+          end
+        end
+
+      it_behaves_like 'ironic conductor'
     end
-
-    let :platform_params do
-      { :conductor_package => 'ironic-conductor',
-        :conductor_service => 'ironic-conductor' }
-    end
-
-    it_configures 'ironic conductor'
-
-    # https://bugs.launchpad.net/cloud-archive/+bug/1572800
-    it 'installs ipmitool package' do
-      is_expected.to contain_package('ipmitool').with(
-        :ensure => 'present',
-        :name   => 'ipmitool',
-        :tag    => ['openstack', 'ironic-package'],
-      )
-    end
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    let :platform_params do
-      { :conductor_service => 'ironic-conductor' }
-    end
-
-    it_configures 'ironic conductor'
   end
 
 end
