@@ -8,9 +8,21 @@ describe 'ironic::db::sync' do
       is_expected.to contain_exec('ironic-dbsync').with(
         :command     => 'ironic-dbsync --config-file /etc/ironic/ironic.conf ',
         :path        => '/usr/bin',
-        :user        => 'root',
+        :user        => 'ironic',
         :refreshonly => 'true',
-        :logoutput   => 'on_failure'
+        :try_sleep   => 5,
+        :tries       => 10,
+        :logoutput   => 'on_failure',
+        :subscribe   => ['Anchor[ironic::install::end]',
+                         'Anchor[ironic::config::end]',
+                         'Anchor[ironic::dbsync::begin]'],
+        :notify      => 'Anchor[ironic::dbsync::end]',
+      )
+
+      is_expected.to contain_file('/var/log/ironic/ironic-dbsync.log').with(
+        :ensure  => 'present',
+        :owner   => 'ironic',
+        :group   => 'ironic',
       )
     end
 
@@ -23,9 +35,15 @@ describe 'ironic::db::sync' do
         it { is_expected.to contain_exec('ironic-dbsync').with(
             :command     => 'ironic-dbsync --config-file /etc/ironic/ironic.conf --config-file /etc/ironic/ironic_01.conf',
             :path        => '/usr/bin',
-            :user        => 'root',
+            :user        => 'ironic',
             :refreshonly => true,
-            :logoutput   => 'on_failure'
+            :try_sleep   => 5,
+            :tries       => 10,
+            :logoutput   => 'on_failure',
+            :subscribe   => ['Anchor[ironic::install::end]',
+                             'Anchor[ironic::config::end]',
+                             'Anchor[ironic::dbsync::begin]'],
+            :notify      => 'Anchor[ironic::dbsync::end]',
         )
         }
     end
@@ -37,12 +55,12 @@ describe 'ironic::db::sync' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
+          :os_workers     => 8,
           :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
 
-      it_configures 'ironic-dbsync'
+      it_behaves_like 'ironic-dbsync'
     end
   end
 
