@@ -30,8 +30,6 @@ describe 'ironic' do
       :database_idle_timeout       => 3600,
       :database_reconnect_interval => 10,
       :database_retry_interval     => 10,
-      :glance_num_retries          => 0,
-      :glance_api_insecure         => false,
       :purge_config                => false,
     }
   end
@@ -45,8 +43,6 @@ describe 'ironic' do
       it_configures 'with SSL enabled with kombu'
       it_configures 'with amqp_durable_queues disabled'
       it_configures 'with amqp_durable_queues enabled'
-      it_configures 'with one glance server'
-      it_configures 'with two glance servers'
     end
 
     context 'and if rabbit_hosts parameter is provided' do
@@ -64,7 +60,7 @@ describe 'ironic' do
       end
     end
 
-    context 'with amqp rpc_backend value' do
+    context 'with amqp messaging' do
       it_configures 'amqp support'
     end
 
@@ -75,6 +71,9 @@ describe 'ironic' do
     it { is_expected.to contain_class('ironic::logging') }
     it { is_expected.to contain_class('ironic::params') }
 
+    it { is_expected.to contain_class('ironic::glance') }
+    it { is_expected.to contain_class('ironic::neutron') }
+
     it 'installs ironic-common package' do
       is_expected.to contain_package('ironic-common').with(
         :ensure => 'present',
@@ -102,6 +101,7 @@ describe 'ironic' do
       is_expected.to contain_ironic_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('oslo_messaging_rabbit/rabbit_password').with_secret( true )
+      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>')
     end
 
     it 'should perform default database configuration' do
@@ -111,17 +111,13 @@ describe 'ironic' do
       is_expected.to contain_ironic_config('database/retry_interval').with_value(params[:database_retry_interval])
     end
 
-    it 'configures glance connection' do
-      is_expected.to contain_ironic_config('glance/glance_num_retries').with_value(params[:glance_num_retries])
-      is_expected.to contain_ironic_config('glance/glance_api_insecure').with_value(params[:glance_api_insecure])
-    end
-
     it 'configures ironic.conf' do
       is_expected.to contain_ironic_config('DEFAULT/auth_strategy').with_value('keystone')
       is_expected.to contain_ironic_config('DEFAULT/my_ip').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>').with_secret(true)
+      is_expected.to contain_ironic_config('DEFAULT/default_resource_class').with_value('<SERVICE DEFAULT>')
     end
   end
 
@@ -154,13 +150,13 @@ describe 'ironic' do
       )
     end
 
-    it do
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('/path/to/ssl/ca/certs')
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('/path/to/ssl/cert/file')
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('/path/to/ssl/keyfile')
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
-    end
+    it { is_expected.to contain_oslo__messaging__rabbit('ironic_config').with(
+      :rabbit_use_ssl     => params[:rabbit_use_ssl],
+      :kombu_ssl_ca_certs => params[:kombu_ssl_ca_certs],
+      :kombu_ssl_certfile => params[:kombu_ssl_certfile],
+      :kombu_ssl_keyfile  => params[:kombu_ssl_keyfile],
+      :kombu_ssl_version  => params[:kombu_ssl_version],
+    )}
   end
 
   shared_examples_for 'with SSL enabled without kombu' do
@@ -170,13 +166,9 @@ describe 'ironic' do
       )
     end
 
-    it do
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('true')
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
-    end
+    it { is_expected.to contain_oslo__messaging__rabbit('ironic_config').with(
+      :rabbit_use_ssl => params[:rabbit_use_ssl],
+    )}
   end
 
   shared_examples_for 'with SSL disabled' do
@@ -186,13 +178,9 @@ describe 'ironic' do
       )
     end
 
-    it do
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('false')
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
-    end
+    it { is_expected.to contain_oslo__messaging__rabbit('ironic_config').with(
+      :rabbit_use_ssl => params[:rabbit_use_ssl],
+    )}
   end
 
 
@@ -208,31 +196,8 @@ describe 'ironic' do
     it { is_expected.to contain_ironic_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true) }
   end
 
-  shared_examples_for 'with one glance server' do
-    before do
-      params.merge!(:glance_api_servers => '10.0.0.1:9292')
-    end
-
-    it 'should configure one glance server' do
-      is_expected.to contain_ironic_config('glance/glance_api_servers').with_value(params[:glance_api_servers])
-    end
-  end
-
-  shared_examples_for 'with two glance servers' do
-    before do
-      params.merge!(:glance_api_servers => ['10.0.0.1:9292','10.0.0.2:9292'])
-    end
-
-    it 'should configure one glance server' do
-       is_expected.to contain_ironic_config('glance/glance_api_servers').with_value(params[:glance_api_servers].join(','))
-    end
-  end
-
   shared_examples_for 'amqp support' do
     context 'with default parameters' do
-      before { params.merge!( :rpc_backend => 'amqp' ) }
-
-      it { is_expected.to contain_ironic_config('DEFAULT/rpc_backend').with_value('amqp') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
@@ -253,7 +218,6 @@ describe 'ironic' do
 
     context 'with overriden amqp parameters' do
       before { params.merge!(
-        :rpc_backend        => 'amqp',
         :amqp_idle_timeout  => '60',
         :amqp_trace         => true,
         :amqp_ssl_ca_file   => '/path/to/ca.cert',
@@ -263,7 +227,6 @@ describe 'ironic' do
         :amqp_password      => 'password',
       ) }
 
-      it { is_expected.to contain_ironic_config('DEFAULT/rpc_backend').with_value('amqp') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_ironic_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
@@ -282,29 +245,30 @@ describe 'ironic' do
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'Debian' })
-    end
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts({
+          :concat_basedir         => '/var/lib/puppet/concat',
+          :fqdn                   => 'some.host.tld',
+        }))
+      end
 
-    let :platform_params do
-      { :common_package_name => 'ironic-common',
-        :lib_package_name    => 'python-ironic-lib' }
-    end
+      let :platform_params do
+        case facts[:osfamily]
+        when 'Debian'
+          { :common_package_name => 'ironic-common',
+            :lib_package_name    => 'python-ironic-lib' }
+        when 'RedHat'
+          { :common_package_name => 'openstack-ironic-common',
+            :lib_package_name    => 'python-ironic-lib' }
+        end
+      end
 
-    it_configures 'ironic'
+      it_behaves_like 'ironic'
+    end
   end
 
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({ :osfamily => 'RedHat' })
-    end
-
-    let :platform_params do
-      { :common_package_name => 'openstack-ironic-common',
-        :lib_package_name    => 'python-ironic-lib' }
-    end
-
-    it_configures 'ironic'
-  end
 end
