@@ -19,40 +19,47 @@
 require 'spec_helper'
 
 describe 'ironic::inspector' do
+  let :pre_condition do
+     "class { 'ironic::inspector::authtoken':
+        password => 'password',
+      }"
+  end
 
   let :params do
-    { :package_ensure                  => 'present',
-      :enabled                         => true,
-      :pxe_transfer_protocol           => 'tftp',
-      :enable_uefi                     => false,
-      :auth_strategy                   => 'keystone',
-      :auth_uri                        => 'http://127.0.0.1:5000/v2.0',
-      :admin_user                      => 'ironic',
-      :admin_password                  => 'password',
-      :admin_tenant_name               => 'services',
-      :identity_uri                    => 'http://127.0.0.1:35357/v2.0',
-      :dnsmasq_interface               => 'br-ctlplane',
-      :db_connection                   => 'sqlite:////var/lib/ironic-inspector/inspector.sqlite',
-      :ramdisk_logs_dir                => '/var/log/ironic-inspector/ramdisk/',
-      :enable_setting_ipmi_credentials => false,
-      :keep_ports                      => 'all',
-      :store_data                      => 'none',
-      :ironic_auth_type                => 'password',
-      :ironic_username                 => 'ironic',
-      :ironic_tenant_name              => 'services',
-      :ironic_auth_url                 => 'http://127.0.0.1:5000/v2.0',
-      :ironic_max_retries              => 30,
-      :ironic_retry_interval           => 2,
-      :swift_auth_type                 => 'password',
-      :swift_username                  => 'ironic',
-      :swift_tenant_name               => 'services',
-      :swift_auth_url                  => 'http://127.0.0.1:5000/v2.0',
-      :dnsmasq_ip_range                => '192.168.0.100,192.168.0.120',
-      :dnsmasq_local_ip                => '192.168.0.1',
-      :ipxe_timeout                    => 0,
-      :http_port                       => 8088,
-      :tftp_root                       => '/tftpboot',
-      :http_root                       => '/httpboot', }
+    { :package_ensure        => 'present',
+      :enabled               => true,
+      :pxe_transfer_protocol => 'tftp',
+      :auth_strategy         => 'keystone',
+      :dnsmasq_interface     => 'br-ctlplane',
+      :ramdisk_logs_dir      => '/var/log/ironic-inspector/ramdisk/',
+      :add_ports             => 'pxe',
+      :keep_ports            => 'all',
+      :store_data            => 'none',
+      :ironic_auth_type      => 'password',
+      :ironic_username       => 'ironic',
+      :ironic_tenant_name    => 'services',
+      :ironic_auth_url       => 'http://127.0.0.1:5000/v2.0',
+      :ironic_max_retries    => 30,
+      :ironic_retry_interval => 2,
+      :swift_auth_type       => 'password',
+      :swift_username        => 'ironic',
+      :swift_tenant_name     => 'services',
+      :swift_auth_url        => 'http://127.0.0.1:5000/v2.0',
+      :dnsmasq_ip_subnets    => [{ 'ip_range' =>
+                                      '192.168.0.100,192.168.0.120' },
+                                 { 'tag'      => 'subnet1',
+                                   'ip_range' => '192.168.1.100,192.168.1.200',
+                                   'netmask'  => '255.255.255.0',
+                                   'gateway'  => '192.168.1.254' },
+                                 { 'tag'      => 'subnet2',
+                                   'ip_range' => '192.168.2.100,192.168.2.200',
+                                   'netmask'  => '255.255.255.0',
+                                   'gateway'  => '192.168.2.254' }],
+      :dnsmasq_local_ip      => '192.168.0.1',
+      :ipxe_timeout          => 0,
+      :http_port             => 8088,
+      :tftp_root             => '/tftpboot',
+      :http_root             => '/httpboot', }
   end
 
 
@@ -94,34 +101,37 @@ describe 'ironic::inspector' do
     it 'configures inspector.conf' do
       is_expected.to contain_ironic_inspector_config('DEFAULT/listen_address').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_inspector_config('DEFAULT/auth_strategy').with_value(p[:auth_strategy])
-      is_expected.to contain_ironic_inspector_config('keystone_authtoken/auth_type').with_value('password')
-      is_expected.to contain_ironic_inspector_config('keystone_authtoken/auth_uri').with_value(p[:auth_uri])
-      is_expected.to contain_ironic_inspector_config('keystone_authtoken/auth_url').with_value(p[:identity_uri])
-      is_expected.to contain_ironic_inspector_config('keystone_authtoken/username').with_value(p[:admin_user])
-      is_expected.to contain_ironic_inspector_config('keystone_authtoken/password').with_value(p[:admin_password])
-      is_expected.to contain_ironic_inspector_config('keystone_authtoken/project_name').with_value(p[:admin_tenant_name])
+      is_expected.to contain_ironic_inspector_config('DEFAULT/timeout').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_inspector_config('capabilities/boot_mode').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_inspector_config('firewall/dnsmasq_interface').with_value(p[:dnsmasq_interface])
-      is_expected.to contain_ironic_inspector_config('database/connection').with_value(p[:db_connection])
       is_expected.to contain_ironic_inspector_config('processing/ramdisk_logs_dir').with_value(p[:ramdisk_logs_dir])
-      is_expected.to contain_ironic_inspector_config('processing/enable_setting_ipmi_credentials').with_value(p[:enable_setting_ipmi_credentials])
+      is_expected.to contain_ironic_inspector_config('processing/add_ports').with_value(p[:add_ports])
       is_expected.to contain_ironic_inspector_config('processing/keep_ports').with_value(p[:keep_ports])
       is_expected.to contain_ironic_inspector_config('processing/store_data').with_value(p[:store_data])
       is_expected.to contain_ironic_inspector_config('ironic/auth_type').with_value(p[:ironic_auth_type])
       is_expected.to contain_ironic_inspector_config('ironic/username').with_value(p[:ironic_username])
       is_expected.to contain_ironic_inspector_config('ironic/project_name').with_value(p[:ironic_tenant_name])
+      is_expected.to contain_ironic_inspector_config('ironic/project_domain_name').with_value('Default')
+      is_expected.to contain_ironic_inspector_config('ironic/user_domain_name').with_value('Default')
       is_expected.to contain_ironic_inspector_config('ironic/auth_url').with_value(p[:ironic_auth_url])
       is_expected.to contain_ironic_inspector_config('ironic/max_retries').with_value(p[:ironic_max_retries])
       is_expected.to contain_ironic_inspector_config('ironic/retry_interval').with_value(p[:ironic_retry_interval])
       is_expected.to contain_ironic_inspector_config('swift/auth_type').with_value(p[:swift_auth_type])
       is_expected.to contain_ironic_inspector_config('swift/username').with_value(p[:swift_username])
       is_expected.to contain_ironic_inspector_config('swift/project_name').with_value(p[:swift_tenant_name])
+      is_expected.to contain_ironic_inspector_config('swift/project_domain_name').with_value('Default')
+      is_expected.to contain_ironic_inspector_config('swift/user_domain_name').with_value('Default')
       is_expected.to contain_ironic_inspector_config('swift/auth_url').with_value(p[:swift_auth_url])
       is_expected.to contain_ironic_inspector_config('processing/processing_hooks').with_value('$default_processing_hooks')
+      is_expected.to contain_ironic_inspector_config('processing/node_not_found_hook').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_inspector_config('discovery/enroll_node_driver').with_value('<SERVICE DEFAULT>')
     end
 
     it 'should contain file /etc/ironic-inspector/inspector.conf' do
       is_expected.to contain_file('/etc/ironic-inspector/inspector.conf').with(
         'ensure'  => 'present',
+        'owner'   => 'ironic-inspector',
+        'group'   => 'ironic-inspector',
         'require' => 'Anchor[ironic-inspector::config::begin]',
       )
     end
@@ -131,6 +141,21 @@ describe 'ironic::inspector' do
         'require' => 'Anchor[ironic-inspector::config::begin]',
         'content' => /pxelinux/,
       )
+      is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+        /dhcp-range=192.168.0.100,192.168.0.120,10m/
+      )
+      is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+        /dhcp-range=set:subnet1,192.168.1.100,192.168.1.200,255.255.255.0,10m/
+      )
+      is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+        /dhcp-option=tag:subnet1,option:router,192.168.1.254/
+      )
+      is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+        /dhcp-range=set:subnet2,192.168.2.100,192.168.2.200,255.255.255.0,10m/
+      )
+      is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+        /dhcp-option=tag:subnet2,option:router,192.168.2.254/
+      )
     end
     it 'should contain file /tftpboot/pxelinux.cfg/default' do
       is_expected.to contain_file('/tftpboot/pxelinux.cfg/default').with(
@@ -151,33 +176,44 @@ describe 'ironic::inspector' do
         params.merge!(
           :debug                       => true,
           :listen_address              => '127.0.0.1',
-          :auth_uri                    => 'http://192.168.0.1:5000/v2.0',
-          :identity_uri                => 'http://192.168.0.1:35357',
-          :admin_password              => 'password',
           :ironic_password             => 'password',
+          :ironic_project_domain_name  => 'Default',
+          :ironic_user_domain_name     => 'Default',
           :ironic_auth_url             => 'http://192.168.0.1:5000/v2.0',
           :swift_password              => 'password',
+          :swift_project_domain_name   => 'Default',
+          :swift_user_domain_name      => 'Default',
           :swift_auth_url              => 'http://192.168.0.1:5000/v2.0',
           :pxe_transfer_protocol       => 'http',
           :additional_processing_hooks => 'hook1,hook2',
           :ramdisk_kernel_args         => 'foo=bar',
-          :enable_uefi                 => true,
           :http_port                   => 3816,
           :tftp_root                   => '/var/lib/tftpboot',
           :http_root                   => '/var/www/httpboot',
+          :detect_boot_mode            => true,
+          :node_not_found_hook         => 'enroll',
+          :discovery_default_driver    => 'pxe_ipmitool',
+          :dnsmasq_ip_subnets          => [],
+          :dnsmasq_ip_range            => '192.168.0.100,192.168.0.120',
+          :add_ports                   => 'all',
         )
       end
       it 'should replace default parameter with new value' do
         is_expected.to contain_ironic_inspector_config('DEFAULT/listen_address').with_value(p[:listen_address])
         is_expected.to contain_ironic_inspector_config('DEFAULT/debug').with_value(p[:debug])
-        is_expected.to contain_ironic_inspector_config('keystone_authtoken/auth_uri').with_value(p[:auth_uri])
-        is_expected.to contain_ironic_inspector_config('keystone_authtoken/auth_url').with_value(p[:identity_uri])
-        is_expected.to contain_ironic_inspector_config('keystone_authtoken/password').with_value(p[:admin_password])
-        is_expected.to contain_ironic_inspector_config('ironic/password').with_value(p[:ironic_password])
+        is_expected.to contain_ironic_inspector_config('capabilities/boot_mode').with_value(p[:detect_boot_mode])
+        is_expected.to contain_ironic_inspector_config('ironic/password').with_value(p[:ironic_password]).with_secret(true)
+        is_expected.to contain_ironic_inspector_config('ironic/project_domain_name').with_value(p[:ironic_project_domain_name])
+        is_expected.to contain_ironic_inspector_config('ironic/user_domain_name').with_value(p[:ironic_user_domain_name])
         is_expected.to contain_ironic_inspector_config('ironic/auth_url').with_value(p[:ironic_auth_url])
-        is_expected.to contain_ironic_inspector_config('swift/password').with_value(p[:swift_password])
+        is_expected.to contain_ironic_inspector_config('swift/password').with_value(p[:swift_password]).with_secret(true)
+        is_expected.to contain_ironic_inspector_config('swift/project_domain_name').with_value(p[:swift_project_domain_name])
+        is_expected.to contain_ironic_inspector_config('swift/user_domain_name').with_value(p[:swift_user_domain_name])
         is_expected.to contain_ironic_inspector_config('swift/auth_url').with_value(p[:swift_auth_url])
         is_expected.to contain_ironic_inspector_config('processing/processing_hooks').with_value('$default_processing_hooks,hook1,hook2')
+        is_expected.to contain_ironic_inspector_config('processing/node_not_found_hook').with_value('enroll')
+        is_expected.to contain_ironic_inspector_config('processing/add_ports').with_value('all')
+        is_expected.to contain_ironic_inspector_config('discovery/enroll_node_driver').with_value('pxe_ipmitool')
       end
 
       it 'should contain file /etc/ironic-inspector/dnsmasq.conf' do
@@ -189,6 +225,15 @@ describe 'ironic::inspector' do
         is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
             /dhcp-boot=tag:ipxe,http:\/\/192.168.0.1:3816\/inspector.ipxe/
         )
+        is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+            /dhcp-range=192.168.0.100,192.168.0.120,10m/
+        )
+        is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+            /log-dhcp/
+        )
+        is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+            /log-queries/
+        )
       end
       it 'should contain file /var/www/httpboot/inspector.ipxe' do
         is_expected.to contain_file('/var/www/httpboot/inspector.ipxe').with(
@@ -219,37 +264,29 @@ describe 'ironic::inspector' do
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily               => 'Debian',
-        :operatingsystem        => 'Debian',
-        :operatingsystemrelease => '7.0'
-      })
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts({
+          :concat_basedir         => '/var/lib/puppet/concat',
+          :fqdn                   => 'some.host.tld',
+        }))
+      end
+
+      let :platform_params do
+        case facts[:osfamily]
+        when 'Debian'
+          { :inspector_package => 'ironic-inspector',
+            :inspector_service => 'ironic-inspector' }
+        when 'RedHat'
+          { :inspector_service => 'ironic-inspector' }
+        end
+      end
+
+      it_behaves_like 'ironic inspector'
     end
-
-    let :platform_params do
-      { :inspector_package => 'ironic-inspector',
-        :inspector_service => 'ironic-inspector' }
-    end
-
-    it_configures 'ironic inspector'
-  end
-
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily               => 'RedHat',
-        :operatingsystem        => 'CentOS',
-        :operatingsystemrelease => '7.2.1511'
-      })
-    end
-
-    let :platform_params do
-      { :inspector_service => 'ironic-inspector' }
-    end
-
-    it_configures 'ironic inspector'
   end
 
 end
